## v0.6.0 (2025-02-05)

### ✨ Features

- add ArrAccessor for getting fit_arr values (#18)
- add visualization of fit stat to DisplayAccessor (#17)

[main 93a0bf0] bump: version 0.5.0 → 0.6.0
 2 files changed, 3 insertions(+), 2 deletions(-)

